package funnel {
	import funnel.IOSystem;
	
	/**
	 * XBeeクラスはDigi InternationalのXBeeシリーズを扱うためのクラスです。
	 * 
	 */ 
	public class XBee extends IOSystem {
		
		/**
		 * XBee 802.15.4用のコンフィギュレーションを取得します。
		 * @return Configurationオブジェクト
		 */
		public static function get MULTIPOINT():Configuration {
			var k:Configuration = new Configuration();
			k.config = [
				AIN, AIN, AIN, AIN, AIN, AIN,
				DIN, DIN
			];
			k.analogPins = [0, 1, 2, 3, 4, 5];
			k.digitalPins = [0, 1, 2, 3, 4, 5, 6, 7];
			return k;
		}

		/**
		 * XBee ZB ZigBee PRO用のコンフィギュレーションを取得します。ただし、D6、D8とD9はモジュールの仕様によりアクセスできません
		 * @return Configurationオブジェクト
		 */
		public static function get ZB():Configuration {
			var k:Configuration = new Configuration();
			k.config = [
				AIN, AIN, AIN, AIN,
				DIN, DIN, DIN, DIN, DIN, DIN, DIN, DIN, DIN
			];
			k.analogPins = [0, 1, 2, 3];
			k.digitalPins = [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12];
			return k;
		}
		
		/**
		 * @param nodes 利用するモジュールのID配列
		 * @param config コンフィギュレーション
		 * @param host ホスト名
		 * @param portNum ポート番号
		 * @param samplingInterval サンプリング間隔(ms)
		 */ 
		public function XBee(nodes:Array = null, config:Configuration = null, host:String = "localhost", portNum:Number = 9000, samplingInterval:int = 33) {
			if (nodes == null) nodes = [];
			if (config == null) config = XBee.MULTIPOINT;
			var configs:Array = [];
			for each (var id:uint in nodes) {
				var c:Configuration = config.clone();
				c.moduleID = id;
				configs.push(c);
			}
			super(configs, host, portNum, samplingInterval);
		}
	}
}
